# Ruby

The Launchable CLI includes built-in integrations for test runners and build tools that are popular in the Ruby ecosystem:

* [minitest](../integrations/minitest.md)
* [RSpec](../integrations/rspec.md)

See each integration's page for instructions to add Launchable to your CI pipeline.

